@@ -27,8 +27,11 @@ extern bool CHKBUT_allowprint_isdef     ();
 extern bool VALINP_printdel_isdef       ();
 extern bool CHKBUT_altsavedir_isdef     ();
 
-extern void CB_SetActualTabToDefaults	();
+extern void CB_SetActualTabToDefaults	  ();
+extern void CB_SetAllTabsToDefaults	    ();
 
+#define DEF_WINDOW_WIDTH WW_800
+#define DEF_WINDOW_HEIGHT WH_600
 
 #endif
 
