@@ -4,15 +4,15 @@
   Tux Paint Configuration Tool - A GUI configuration editor for Tux Paint,
                                  a simpel drawing program for children.
 
-  Copyright (c) 2004
+  Copyright (c) 2002-2007
   
   Torsten Giebl <wizard@turricane.org>
   Jan Wynholds
   Bill Kendrick <bill@newbreedsoftware.com>
 
-  http://www.newbreedsoftware.com/tuxpaint/
+  http://www.tuxpaint.org/
   
-  November 12, 2002 - October 2, 2004
+  November 12, 2002 - June 25, 2007
 */
 
 
@@ -27,22 +27,16 @@
 #define gettext_noop(String) String
 #endif
 
+#if !defined (__WIN32__) && !defined(__APPLE__) && !defined(__BEOS__)
+#include <paper.h>
+#endif
+
 #include "version.h"
 #include "about.h"
 
 
 #ifdef WIN32
-
-extern char * g_win32_getlocale(void);
-
-#define DOC_PREFIX "docs/"
-#define DATA_PREFIX "data/"
 #define LOCALEDIR "locale"
-
-#define strcasecmp    stricmp
-#define strncasecmp   strnicmp
-#define snprintf      _snprintf
-
 #endif
 
 #include <errno.h>
@@ -61,26 +55,6 @@ extern char * g_win32_getlocale(void);
 
 #include "tuxpaint-config2.h"
 
-#ifdef WIN32
-/*
- *   The SDL stderr redirection trick doesn't seem to work for perror().
- *     This does pretty much the same thing.
- *     */
-void win32_perror(const char *str)
-{
-  if ( str && *str )
-      fprintf(stderr,"%s : ",str);
-
-  fprintf(stderr, "%s [%d]\n",
-          (errno<_sys_nerr)?_sys_errlist[errno]:"unknown",errno );
-}
-
-#define perror         win32_perror
-#endif
-
-
-
-
 /* Local function prototypes: */
 
 void setup(int argc, char * argv[]);
@@ -89,9 +63,17 @@ int mainloop(int argc, char * argv[]);
 
 int main(int argc, char * argv[])
 {
+  int res;
+
   setup(argc, argv);
 
-  return ( mainloop(argc, argv) );
+  res = mainloop(argc, argv);
+
+#if !defined (__WIN32__) && !defined(__APPLE__) && !defined(__BEOS__)
+  paperdone();
+#endif
+
+  return res;
 }
 
 
@@ -109,6 +91,8 @@ void setup(int argc, char * argv[])
   int i;
   int show_usage;
   int exit_val;
+  const struct paper * ppr;
+  int max_papersizes;
 
   show_usage = 0;
   exit_val = 0;
@@ -117,7 +101,35 @@ void setup(int argc, char * argv[])
   {
     if (strcmp(argv[i], "--help") == 0)
     {
-      printf("%s\n", about_text);
+      unsigned int x, j, len;
+      char buf[80];
+
+      buf[0] = '\0';
+      len = 0;
+      x = 0;
+
+      for (j = 0; j <= strlen(about_text); j++)
+      {
+        buf[len++] = about_text[j];
+
+        if (about_text[j] == ' ' || about_text[j] == '\0')
+        {
+          if (x + len > 78)
+          {
+            printf("\n");
+            x = 0;
+          }
+
+          buf[len] = '\0';
+          printf("%s", buf);
+          x += len;
+
+          len = 0;
+        }
+      }
+
+      printf("\n\n");
+
       exit(0);
     }
     else if (strcmp(argv[i], "--usage") == 0)
@@ -178,5 +190,37 @@ void setup(int argc, char * argv[])
 
   textdomain("tuxpaint-config");
 
+#endif
+
+
+  /* Get available paper sizes: */
+
+#if !defined (__WIN32__) && !defined(__APPLE__) && !defined(__BEOS__)
+  paperinit();
+
+  max_papersizes = 5;
+  papersizes = (char * *) malloc(sizeof (char * *) * max_papersizes);
+
+  papersizes[0] = strdup("(Use system's default)");
+  num_papersizes = 1;
+  ppr = paperfirst();
+  
+  do
+  {
+    if (ppr != NULL)
+    {
+      if (num_papersizes >= max_papersizes)
+      {
+        max_papersizes += 5;
+        papersizes = (char * *) realloc(papersizes, sizeof(char * *) * max_papersizes);
+      }
+
+      papersizes[num_papersizes++] = strdup(papername(ppr));
+    }
+
+    ppr = papernext(ppr);
+  }
+  while (ppr != NULL);
+
 #endif
 }
